@@ -3,7 +3,9 @@
 
 import os
 import shutil
+import io
 
+from utils import file_write_legacy
 
 class Fixtures:
 
@@ -118,9 +120,7 @@ class Fixtures:
             newly_created.append(subdir)
 
         for fname in ('a', subdir + '/b'):
-            fhandle = open(fname, 'w')
-            fhandle.write(str(new_rev))
-            fhandle.close()
+            file_write_legacy(fname, new_rev)
             self.scmlogs.annotate("Wrote %s to %s" % (new_rev, fname))
 
         # we never commit through symlink 'c' but instead see the updated
@@ -156,9 +156,7 @@ class Fixtures:
 
         new_rev = self.next_commit_rev(wdir)
         fname = 'd'
-        cfh = open(fname, 'w')
-        cfh.write(str(new_rev))
-        cfh.close()
+        file_write_legacy(fname, new_rev)
         self.scmlogs.annotate("Wrote %s to %s" % (new_rev, fname))
         self.safe_run('add .')
         date = self.get_committer_date()
@@ -167,7 +165,8 @@ class Fixtures:
         self.scmlogs.annotate("Created 1 commit; now at %s" % (new_rev))
 
     def touch(self, fname, times=None):
-        with open(os.path.join(self.wdir, fname), 'a'):
+        fpath = os.path.join(self.wdir, fname)
+        with io.open(fpath, 'a', encoding='UTF-8'):
             os.utime(fname, times)
 
     def remove(self, fname):
