@@ -5,9 +5,10 @@ from __future__ import print_function
 
 import os
 import re
+import io
 import shutil
 import subprocess
-import six
+import sys
 
 
 def mkfreshdir(path):
@@ -21,14 +22,32 @@ def mkfreshdir(path):
     os.makedirs(path)
     os.chdir(cwd)
 
+def check_locale(loc):
+    try:
+        aloc_tmp = subprocess.check_output(['locale', '-a'])
+    except AttributeError:
+        aloc_tmp, _ = subprocess.Popen(['locale', '-a'],
+                                       stdout=subprocess.PIPE,
+                                       stderr=subprocess.STDOUT).communicate()
+    aloc = {}
+
+    for tloc in aloc_tmp.split(b'\n'):
+        aloc[tloc] = 1
+
+    for tloc in loc:
+        print("Checking .... %s"%tloc, file=sys.stderr)
+        try:
+            if aloc[tloc.encode()]:
+                return tloc
+        except KeyError:
+            pass
+
+    return 'C'
 
 def run_cmd(cmd):
-    os.putenv('LANG', 'C.utf-8')
-    os.putenv('LC_ALL', 'C.utf-8')
-    os.environ['LANG'] = 'C.utf-8'
-    os.environ['LC_ALL'] = 'C.utf-8'
-    if six.PY3:
-        cmd = cmd.encode('UTF-8')
+    use_locale = check_locale(["en_US.utf8", 'C.utf8'])
+    os.environ['LANG']   = use_locale
+    os.environ['LC_ALL'] = use_locale
     proc = subprocess.Popen(
         cmd,
         shell=True,
@@ -70,3 +89,13 @@ def run_hg(repo, args):
 
 def run_bzr(repo, args):
     return run_scm('bzr', repo, args)
+
+def file_write_legacy(fname, string, *args):
+    '''function to write string to file python 2/3 compatible'''
+    mode = 'w'
+    if args:
+        mode = args[0]
+
+    with io.open(fname, mode, encoding='utf-8') as outfile:
+        # 'str().encode().decode()' is required for pyhton 2/3 compatibility
+        outfile.write(str(string).encode('UTF-8').decode('UTF-8'))
